install_dir  0755 root wheel   '/etc'
install_file 0644 root wheel   '/etc/acme-client.conf'
install_file 0600 root wheel   '/etc/doas.conf'
install_file 0644 root wheel   '/etc/exports'
install_file 0644 root wheel   '/etc/fstab'
install_file 0644 root wheel   '/etc/hosts'
install_file 0644 root wheel   '/etc/httpd.conf'
install_dir  0755 root wheel   '/etc/httpd'
install_file 0644 root wheel   '/etc/httpd/_acme.conf'
install_file 0644 root wheel   '/etc/httpd/_listen80.conf'
install_file 0644 root wheel   '/etc/httpd/_listen443.conf'
install_file 0644 root wheel   '/etc/my.cnf'
install_file 0600 root wheel   '/etc/pf.conf'
install_file 0644 root wheel   '/etc/php-8.3.ini'
install_file 0644 root wheel   '/etc/rc.conf.local'
install_file 0644 root wheel   '/etc/shells'
install_dir  0755 root wheel   '/etc/ssh'
install_file 0644 root wheel   '/etc/ssh/sshd_config'

install_dir  0755 root wheel   '/home'
install_dir  0755 git  git     '/home/git'
install_file 0644 git  git     '/home/git/.gitconfig'
install_file 0600 git  git     '/home/git/.gitolite.rc'

install_dir  0755 root daemon  '/var'
install_dir  0555 root wheel   '/var/cron'
install_dir  1730 root crontab '/var/cron/tabs'
install_file 0600 root crontab '/var/cron/tabs/root'
install_dir  0755 root daemon  '/var/www'
install_dir  0755 root daemon  '/var/www/conf'
install_file 0644 root wheel   '/var/www/conf/cgitrc'
install_dir  0755 git  git     '/var/www/git'
install_dir  0755 git  git     '/var/www/git/repositories'
install_dir  0755 root wheel   '/var/www/htdocs/PhoenixCart-1.1.0.7'
install_dir  0755 root wheel   '/var/www/htdocs/PhoenixCart-1.1.0.7/includes'
install_dir  0755 root wheel   '/var/www/htdocs/PhoenixCart-1.1.0.7/admin/includes'
install_file 0644 root wheel   '/var/www/htdocs/PhoenixCart-1.1.0.7/includes/configure.php'
install_file 0644 root wheel   '/var/www/htdocs/PhoenixCart-1.1.0.7/admin/includes/configure.php'
