delete_file() {
    path="$1"

    if [ "$DELETE_OBSOLETE" = 'YES' ]; then
        if [ -e "$path" -o -e "$path.old" ]; then
            echo '==='
            if [ -e "$path"     ]; then echo "rm -f \"$path\"";     fi
            if [ -e "$path.old" ]; then echo "rm -f \"$path.old\""; fi
            if [ "$DRY" != 'YES' ]; then
                rm -f "$path" "$path.old"
	    fi
        fi
    fi
}
