<?php
  error_reporting(E_ALL);

  const HTTP_SERVER = 'https://bookcorner.ge';
  const COOKIE_OPTIONS = [
    'lifetime' => 0,
    'domain' => 'bookcorner.ge',
    'path' => '/admin',
    'samesite' => 'Lax',
    'secure' => true,
  ];
  const DIR_WS_ADMIN = '/admin/';

  const HTTP_CATALOG_SERVER = 'https://bookcorner.ge';
  const DIR_WS_CATALOG = '/';

  date_default_timezone_set('Asia/Tbilisi');

  const DIR_FS_CATALOG = '/htdocs/PhoenixCart-1.1.0.7/';

  const DIR_FS_DOCUMENT_ROOT = '/htdocs/PhoenixCart-1.1.0.7/';
  const DIR_FS_ADMIN = '/htdocs/PhoenixCart-1.1.0.7/admin/';
  const DIR_FS_BACKUP = DIR_FS_ADMIN . 'backups/';

// If you are asked to provide configure.php details,
// before sharing, please remove the data below and
// obfuscate the admin folder and home directory (DIR_FS).
  const DB_SERVER = '127.0.0.1';
  const DB_SERVER_USERNAME = 'phoenixcart';
  const DB_SERVER_PASSWORD = 'h8wr8zsmzivqjvlxh5odpex4zah4anar';
  const DB_DATABASE = 'phoenixcart';
