<?php
  error_reporting(E_ALL);

  const HTTP_SERVER = 'https://bookcorner.ge';
  const COOKIE_OPTIONS = [
    'lifetime' => 0,
    'domain' => 'bookcorner.ge',
    'path' => '/',
    'samesite' => 'Lax',
    'secure' => true,
  ];
  const DIR_WS_CATALOG = '/';

  date_default_timezone_set('Asia/Tbilisi');

// If you are asked to provide configure.php details,
// please remove the data below before sharing.
  const DIR_FS_CATALOG = '/htdocs/PhoenixCart-1.1.0.7/';

  const DB_SERVER = '127.0.0.1';
  const DB_SERVER_USERNAME = 'phoenixcart';
  const DB_SERVER_PASSWORD = 'h8wr8zsmzivqjvlxh5odpex4zah4anar';
  const DB_DATABASE = 'phoenixcart';
