delete_dir() {
    path="$1"

    if [ "$DELETE_OBSOLETE" = 'YES' ]; then
        if [ -e "$path" ]; then
            echo '==='
            echo "rmdir \"$path\""
            if [ "$DRY" != 'YES' ]; then
                rmdir "$path"
	    fi
        fi
    fi
}
